// 定义工艺路线步骤的接口
export interface ProdBaseRouteProcess {
  /** 工艺路线步骤ID */
  routeProcessId?: number;
  /** 工艺路线ID */
  routeId?: number;
  /** 工序ID */
  processId: string | number;
  /** 工序名称 */
  processName?: string;
  /** 工序类型 */
  processType?: string;
  /** 工序顺序 */
  processOrder: string | number;
  /** 委外标识 */
  outsourcingFlag?: string;
  /** 工序类型 */
  operationType?: string;
  /** 是否需要上料 */
  needFeeding?: string;
  /** 设备点检 */
  needEquipmentCheck?: string;
  /** 实际产出率 */
  actualYieldRate?: number;
  /** 领料方式 */
  materialIssuance?: string;
  /** 委外提前期 */
  outsourcingLeadTime?: number;
  /** 准备时间 */
  setupTime?: number;
  /** 加工时间 */
  processingTime?: number;
  /** 拆卸时间 */
  teardownTime?: number;
  /** 生产节拍 */
  productionTakt?: number;
  /** 质检方式 */
  inspectionMethod?: string;
  /** 质量检验规则ID */
  qualityRuleId?: string;
  /** 关键工序 */
  isKeyOperation?: string;
  /** 下工序要求 */
  nextStepRequirement?: string;
  /** 最后工序 */
  isFinalStep?: string;
  /** 生成流转卡任务 */
  generatePrepareTask?: string;
  /** 瓶颈工序 */
  bottleneckFlag?: string;
  /** 瓶颈设置 */
  bottleneckSetting?: string;
  /** 接续关系 */
  successorRelation?: string;
  /** 偏置时间 */
  offsetTime?: number;
  /** 技术附件 */
  techAttachments?: string;
  /** 质检员 */
  inspectors?: string;
  /** 备注 */
  remark?: string;
  /** 创建人 */
  createBy?: number;
  /** 创建时间 */
  createTime?: string;
  /** 更新人 */
  updateBy?: number;
  /** 更新时间 */
  updateTime?: string;
  /** 序号（前端使用） */
  index?: number;
}

// 定义工艺路线关联物料的接口
export interface ProdBaseRouteMaterial {
  /** 物料ID */
  materialId: string | number;
  /** 物料名称 */
  materialName?: string;
  /** 激活标识（0否 1是） */
  activeFlag: string;
  /** 备注 */
  remark?: string;
  /** 创建人 */
  createBy?: number;
  /** 创建时间 */
  createTime?: string;
  /** 更新人 */
  updateBy?: number;
  /** 更新时间 */
  updateTime?: string;
  /** 序号（前端使用） */
  index?: number;
}

export interface BaseRouteVO {
  /**
   * 工艺路线ID
   */
  routeId: string | number;

  /**
   * 租户编号
   */
  tenantId: string | number;

  /**
   * 工艺路线名称
   */
  routeName: string;

  /**
   * 工艺路线说明
   */
  routeDesc: string;

  /**
   * 状态（1待审核 2审核通过 3审核不通过 4发布 5作废）
   */
  activeFlag: string;

  /**
   * 备注
   */
  remark: string;

  /**
   * 创建部门
   */
  createDept: number;

  /**
   * 创建人
   */
  createBy: number;

  /**
   * 创建时间
   */
  createTime: string;

  /**
   * 更新人
   */
  updateBy: number;

  /**
   * 更新时间
   */
  updateTime: string;

  /**
   * 工艺路线步骤列表
   */
  routeProcessBoList?: ProdBaseRouteProcess[];

  routeProcessVoList?: ProdBaseRouteProcess[];

  /**
   * 工艺路线关联物料列表
   */
  prodBaseRouteMaterialList?: ProdBaseRouteMaterial[];

  /**
   * 工艺路线版本
   */
  routeVersion: string;

  /**
   * 生产类型（1正式 2试制 3返修）
   */
  productionType: string;

  /**
   * 路线类型（1生产 2装配）
   */
  routeType: string;

  /**
   * 审核原因
   */
  auditReason: string;

  /**
   * 审核人
   */
  approveBy: number;

  /**
   * 审核时间
   */
  approveTime: string;

  /**
   * 是否需要首件检验（0否 1是）
   */
  needFirstInspect: string;

  /**
   * 是否打印流转卡（0继承 1是 2否）
   */
  printFlowCard: string;

  /**
   * 批次量（0=不拆分）
   */
  batchSize: number;
}

export interface BaseRouteForm extends BaseEntity {
  /**
   * 工艺路线ID
   */
  routeId?: string | number;

  /**
   * 工艺路线名称
   */
  routeName?: string;

  /**
   * 工艺路线说明
   */
  routeDesc?: string;

  /**
   * 状态（1待审核 2审核通过 3审核不通过 4发布 5作废）
   */
  activeFlag?: string;

  /**
   * 备注
   */
  remark?: string;

  /**
   * 工艺路线步骤列表
   */
  routeProcessBoList?: ProdBaseRouteProcess[];

  routeProcessVoList?: ProdBaseRouteProcess[];

  /**
   * 工艺路线关联物料列表
   */
  prodBaseRouteMaterialList?: ProdBaseRouteMaterial[];

  /**
   * 工艺路线版本
   */
  routeVersion?: string;

  /**
   * 生产类型（1正式 2试制 3返修）
   */
  productionType?: string;

  /**
   * 路线类型（1生产 2装配）
   */
  routeType?: string;

  /**
   * 审核原因
   */
  auditReason?: string;

  /**
   * 审核人
   */
  approveBy?: number;

  /**
   * 审核时间
   */
  approveTime?: string;

  /**
   * 是否需要首件检验（0否 1是）
   */
  needFirstInspect?: string;

  /**
   * 是否打印流转卡（0继承 1是 2否）
   */
  printFlowCard?: string;

  /**
   * 批次量（0=不拆分）
   */
  batchSize?: number;
}

export interface BaseRouteQuery extends PageQuery {
  /**
   * 工艺路线ID
   */
  routeId?: string | number;

  /**
   * 工艺路线名称
   */
  routeName?: string;

  /**
   * 工艺路线说明
   */
  routeDesc?: string;

  /**
   * 状态（1待审核 2审核通过 3审核不通过 4发布 5作废）
   */
  activeFlag?: string;

  /**
   * 工艺路线版本
   */
  routeVersion?: string;

  /**
   * 生产类型（1正式 2试制 3返修）
   */
  productionType?: string;

  /**
   * 路线类型（1生产 2装配）
   */
  routeType?: string;

  /**
   * 审核原因
   */
  auditReason?: string;

  /**
   * 审核人
   */
  approveBy?: number;

  /**
   * 审核时间
   */
  approveTime?: string;

  /**
   * 是否需要首件检验（0否 1是）
   */
  needFirstInspect?: string;

  /**
   * 是否打印流转卡（0继承 1是 2否）
   */
  printFlowCard?: string;

  /**
   * 批次量（0=不拆分）
   */
  batchSize?: number;

  /**
   * 日期范围参数
   */
  params?: any;
}



