import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ToolingTypeVO, ToolingTypeForm, ToolingTypeQuery } from '@/api/mes/toolingType/types';

/**
 * 查询载具工装类型列表
 * @param query
 * @returns {*}
 */

export const listToolingType = (query?: ToolingTypeQuery): AxiosPromise<ToolingTypeVO[]> => {
  return request({
    url: '/mes/toolingType/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询载具工装类型详细
 * @param toolingTypeId
 */
export const getToolingType = (toolingTypeId: string | number): AxiosPromise<ToolingTypeVO> => {
  return request({
    url: '/mes/toolingType/' + toolingTypeId,
    method: 'get'
  });
};

/**
 * 新增载具工装类型
 * @param data
 */
export const addToolingType = (data: ToolingTypeForm) => {
  return request({
    url: '/mes/toolingType',
    method: 'post',
    data: data
  });
};

/**
 * 修改载具工装类型
 * @param data
 */
export const updateToolingType = (data: ToolingTypeForm) => {
  return request({
    url: '/mes/toolingType',
    method: 'put',
    data: data
  });
};

/**
 * 删除载具工装类型
 * @param toolingTypeId
 */
export const delToolingType = (toolingTypeId: string | number | Array<string | number>) => {
  return request({
    url: '/mes/toolingType/' + toolingTypeId,
    method: 'delete'
  });
};


/**
 * 下拉框查询载具工装类型列表
 * @param query
 * @returns {*}
 */
export function getBaseToolingTypeList (query) {
    return request({
        url: '/mes/toolingType/getBaseToolingTypeList',
        method: 'get',
        params: query
    });
};
